#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-BqVNStpALLSC4fORH7JBon
key:                  dhall-1.42.3-BqVNStpALLSC4fORH7JBon
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  9eaa3207614bb4b1c45f385a71a41f77
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-BqVNStpALLSC4fORH7JBon
depends:
    Diff-0.5-D4M1kBsQ9qPFmAEZP846cU
    aeson-2.2.2.0-CRLoVrOByflKEQQ5tNkVEn
    aeson-pretty-0.8.10-9dzc5aNofu3FP3zKb1fh7N
    ansi-terminal-1.1-6Y22U2Ur51rJg2I79RgMg8
    atomic-write-0.2.1.1-Ke2Fkg8lPbB4qLrCLBEyBj base-4.18.2.1
    base16-bytestring-1.0.2.0-AMtBRFHYCKP9ubQlj6HdMp
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-1ETr6xFTAun2xxhtwouJyo
    cborg-0.2.10.0-5PLmbH198uS1DgoMEmWgB9
    cborg-json-0.2.6.0-9zgI03PbU44xW4yezXHKO containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-3MkiXBFKcWf9bm3TL3xyca
    data-fix-0.3.4-HoZ4BCOikxlECT4rwHwkUF deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-9DbVm8pPqLN9PX1b0z8KDo exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-FDgtluZHXC32TLalSMRiE3
    hashable-1.4.7.0-D6t6qvvDqS783ayXdNNEFV haskeline-0.8.2.1
    http-client-0.7.19-1q3y7vnpuvH51ds1r9Weyk
    http-client-tls-0.3.6.4-KIkmAPoOGiF5239aT5EBjl
    http-types-0.12.4-DWpoveyaOeC1PmowHzh97w
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-FrqBcE6xAtMAjUGpKC31HV
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    optparse-applicative-0.18.1.0-LsOKtOqLyEnLWzHgVmzESB
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-7RMCng4aCJy44DoAR7KPHI
    pretty-simple-4.1.4.0-FW6nXX9ey1IBWH46Md6sUO
    prettyprinter-1.7.1-52j8P4oMnu1E1CFeo6hQyT
    prettyprinter-ansi-terminal-1.1.3-JUuujg3qpk3H3SinOXjFJ1
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-31CWcid3qo6Aj4OF43pUKd
    serialise-0.2.6.1-GABsOLB19w45AaXv4Lp29B template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-CfMtnQuDHRgGt8FFLB0qRN
    text-short-0.1.6.1-Lbois4yWyDJEmpZWFGNH8X
    th-lift-instances-0.1.20-IPInef9iCL9AKx7SoFlN8g time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-EYHAsit1fL11kLRdxVRh0d
    unordered-containers-0.2.20.1-170HxTRPWLJC6Js92iIt2k
    vector-0.13.2.0-LuonB4ieSbk1FHCVO4HoCK

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

